@@ -13,7 +13,7 @@ try:  # py27
 except ImportError:
     from urllib import pathname2url
 
-from pip_api._vendor.packaging import requirements, specifiers
+from packaging import requirements, specifiers
 
 from pip_api.exceptions import PipError
 
